@@ -86,7 +86,7 @@ class Chord : public ChordRest {
 
       Arpeggio*           _arpeggio;
       Tremolo*            _tremolo;
-      bool                _endsGlissando;///< true if this chord is the ending point of a glissando (nneeded for layout)
+      bool                _endsGlissando;///< true if this chord is the ending point of a glissando (needed for layout)
       ElementList         _el;           ///< chordline, slur
       QList<Chord*>       _graceNotes;
       int                 _graceIndex;   ///< if this is a grace note, index in parent list
@@ -156,9 +156,9 @@ class Chord : public ChordRest {
       Arpeggio* arpeggio() const             { return _arpeggio;  }
       Tremolo* tremolo() const               { return _tremolo;   }
       void setTremolo(Tremolo* t)            { _tremolo = t;      }
-//      Glissando* glissando() const           { return _glissando; }
       bool endsGlissando() const             { return _endsGlissando; }
       void setEndsGlissando (bool val)       { _endsGlissando = val; }
+      void updateEndsGlissando();
       StemSlash* stemSlash() const           { return _stemSlash; }
       bool slash();
       void setSlash(bool flag, bool stemless);
@@ -188,6 +188,7 @@ class Chord : public ChordRest {
 
       Note* selectedNote() const;
       virtual void layout();
+      virtual QPointF pagePos() const override;      ///< position in page coordinates
       void layout2();
       void cmdUpdateNotes(AccidentalState*);
 
@@ -197,7 +198,7 @@ class Chord : public ChordRest {
       void toGraceAfter();
       virtual void scanElements(void* data, void (*func)(void*, Element*), bool all=true);
 
-      virtual void setTrack(int val);
+      virtual void setTrack(int val) override;
 
       void computeUp();
 
