@@ -159,6 +159,7 @@ void Cursor::addNote(int pitch)
       {
       NoteVal nval(pitch);
       _score->addPitch(nval, false);
+      _segment = _score->inputState().segment();
       }
 
 //---------------------------------------------------------
@@ -191,6 +192,15 @@ double Cursor::time()
       return _score->utick2utime(tick()) * 1000;
       }
 
+//---------------------------------------------------------
+//   tempo
+//---------------------------------------------------------
+
+qreal Cursor::tempo()
+      {
+      return _score->tempo(tick());
+      }
+
 //---------------------------------------------------------
 //   element
 //---------------------------------------------------------
