@@ -35,7 +35,7 @@ FretDiagram::FretDiagram(Score* score)
       {
       setFlags(ElementFlag::MOVABLE | ElementFlag::ON_STAFF | ElementFlag::SELECTABLE);
       font.setFamily("FreeSans");
-      int size = lrint(4.0 * MScore::DPI * mag()/ PPI);
+      int size = lrint(4.0 * mag());
       font.setPixelSize(size);
       }
 
@@ -80,6 +80,47 @@ FretDiagram::~FretDiagram()
       delete[] _fingering;
       }
 
+//---------------------------------------------------------
+//   fromString
+///  Create diagram from string like "XO-123"
+///  Always assume barre on the first visible fret
+//---------------------------------------------------------
+
+FretDiagram* FretDiagram::fromString(Score* score, const QString &s)
+      {
+      FretDiagram* fd = new FretDiagram(score);
+      fd->setStrings(s.size());
+      fd->setFrets(4);
+      int offset = 0;
+      int barreString = -1;
+      for (int i = 0; i < s.size(); i++) {
+            QChar c = s.at(i);
+            if (c == 'X' or c == 'O')
+                  fd->setMarker(i, c.toAscii());
+            else if (c == '-' && barreString == -1) {
+                  fd->setBarre(1);
+                  barreString = i;
+                  }
+            else {
+                  int fret = c.digitValue();
+                  if (fret != -1) {
+                        fd->setDot(i, fret);
+                        if (fret - 3 > 0 && offset < fret - 3)
+                            offset = fret - 3;
+                        }
+                  }
+            }
+      if (offset > 0) {
+            fd->setOffset(offset);
+            for (int i = 0; i < fd->strings(); i++)
+                  if (fd->dot(i))
+                        fd->setDot(i, fd->dot(i) - offset);
+            }
+      if (barreString >= 0)
+            fd->setDot(barreString, 1);
+      return fd;
+      }
+
 //---------------------------------------------------------
 //   pagePos
 //---------------------------------------------------------
@@ -106,6 +147,19 @@ QPointF FretDiagram::pagePos() const
 
 QLineF FretDiagram::dragAnchor() const
       {
+      qreal xp = 0.0;
+      for (Element* e = parent(); e; e = e->parent())
+            xp += e->x();
+      qreal yp;
+      if (parent()->type() == Element::Type::SEGMENT) {
+            System* system = static_cast<Segment*>(parent())->measure()->system();
+            yp = system->staffCanvasYpage(staffIdx());
+            }
+      else
+            yp = parent()->canvasPos().y();
+      QPointF p1(xp, yp);
+      return QLineF(p1, canvasPos());
+#if 0 // TODOxx
       if (parent()->type() == Element::Type::SEGMENT) {
             Segment* s     = static_cast<Segment*>(parent());
             Measure* m     = s->measure();
@@ -116,7 +170,6 @@ QLineF FretDiagram::dragAnchor() const
 
             qreal x  = 0.0;
             qreal y  = 0.0;
-#if 0 // TODOxx
             qreal tw = width();
             qreal th = height();
             if (_align & AlignmentFlags::BOTTOM)
@@ -129,10 +182,10 @@ QLineF FretDiagram::dragAnchor() const
                   x = tw;
             else if (_align & AlignmentFlags::HCENTER)
                   x = (tw * .5);
-#endif
             return QLineF(p1, abbox().topLeft() + QPointF(x, y));
             }
       return QLineF(parent()->pagePos(), abbox().topLeft());
+#endif
       }
 
 //---------------------------------------------------------
@@ -220,14 +273,14 @@ void FretDiagram::draw(QPainter* painter) const
       painter->setPen(pen);
       painter->setBrush(QBrush(QColor(painter->pen().color())));
       qreal x2 = (_strings-1) * stringDist;
-      painter->drawLine(QLineF(-lw1*.5, 0.0, x2+lw1*.5, 0.0));
+      painter->drawLine(QLineF(-lw1 * .5, 0.0, x2 + lw1 * .5, 0.0));
 
       pen.setWidthF(lw1);
       painter->setPen(pen);
-      qreal y2 = (_frets+1) * fretDist - fretDist*.5;
+      qreal y2 = (_frets+1) * fretDist - fretDist * .5;
       for (int i = 0; i < _strings; ++i) {
             qreal x = stringDist * i;
-            painter->drawLine(QLineF(x, _fretOffset ? -_spatium*.2 : 0.0, x, y2));
+            painter->drawLine(QLineF(x, _fretOffset ? -_spatium * .2 : 0.0, x, y2));
             }
       for (int i = 1; i <= _frets; ++i) {
             qreal y = fretDist * i;
@@ -238,7 +291,7 @@ void FretDiagram::draw(QPainter* painter) const
       qreal dotd = stringDist * .6;
 
       for (int i = 0; i < _strings; ++i) {
-            if (_dots && _dots[i]) {
+            if (_dots && _dots[i] && _dots[i] != _barre) {
                   int fret = _dots[i] - 1;
                   qreal x = stringDist * i - dotd * .5;
                   qreal y = fretDist * fret + fretDist * .5 - dotd * .5;
@@ -247,7 +300,7 @@ void FretDiagram::draw(QPainter* painter) const
             if (_marker && _marker[i]) {
                   qreal x = stringDist * i;
                   qreal y = -fretDist * .3 - fm.ascent();
-                  painter->drawText(QRectF(x, y, .0,.0),
+                  painter->drawText(QRectF(x, y, .0, .0),
                      Qt::AlignHCenter|Qt::TextDontClip, QChar(_marker[i]));
                   }
             }
@@ -272,9 +325,9 @@ void FretDiagram::draw(QPainter* painter) const
       if (_fretOffset > 0) {
             qreal fretNumMag = score()->styleD(StyleIdx::fretNumMag);
             QFont scaledFont(font);
-            scaledFont.setPixelSize(font.pixelSize() * fretNumMag);
+            scaledFont.setPixelSize(font.pixelSize() * fretNumMag * _userMag);
             painter->setFont(scaledFont);
-            if ( score()->styleI(StyleIdx::fretNumPos) == 0 )
+            if (score()->styleI(StyleIdx::fretNumPos) == 0)
                   painter->drawText(QRectF(-stringDist *.4, .0, .0, fretDist),
                      Qt::AlignVCenter|Qt::AlignRight|Qt::TextDontClip,
                      QString("%1").arg(_fretOffset+1));
@@ -298,7 +351,7 @@ void FretDiagram::layout()
       stringDist      = _spatium * .7;
       fretDist        = _spatium * .8;
 
-      qreal w = stringDist * (_strings-1);
+      qreal w = stringDist * (_strings - 1);
       qreal h = _frets * fretDist + fretDist * .5;
       qreal y = 0.0;
       qreal dotd = stringDist * .6;
@@ -337,12 +390,9 @@ void FretDiagram::write(Xml& xml) const
       xml.stag("FretDiagram");
       Element::writeProperties(xml);
 
-      if (_strings != DEFAULT_STRINGS)
-            xml.tag("strings", _strings);
-      if (_frets != DEFAULT_FRETS)
-            xml.tag("frets", _frets);
-      if (_fretOffset)
-            xml.tag("fretOffset", _fretOffset);
+      writeProperty(xml, P_ID::FRET_STRINGS);
+      writeProperty(xml, P_ID::FRET_FRETS);
+      writeProperty(xml, P_ID::FRET_OFFSET);
       for (int i = 0; i < _strings; ++i) {
             if ((_dots && _dots[i]) || (_marker && _marker[i]) || (_fingering && _fingering[i])) {
                   xml.stag(QString("string no=\"%1\"").arg(i));
@@ -355,8 +405,7 @@ void FretDiagram::write(Xml& xml) const
                   xml.etag();
                   }
             }
-      if (_barre)
-            xml.tag("barre", _barre);
+      writeProperty(xml, P_ID::FRET_BARRE);
       writeProperty(xml, P_ID::MAG);
       if (_harmony)
             _harmony->write(xml);
@@ -492,9 +541,9 @@ Element* FretDiagram::drop(const DropData& data)
       {
       Element* e = data.element;
       if (e->type() == Element::Type::HARMONY) {
-            // TODO: make undoable
             Harmony* h = static_cast<Harmony*>(e);
-            h->setParent(this);
+            h->setParent(parent());
+            h->setTrack((track() / VOICES) * VOICES);
             score()->undoAddElement(h);
             }
       else {
@@ -581,35 +630,88 @@ void FretDiagram::readMusicXML(XmlReader& e)
 void FretDiagram::writeMusicXML(Xml& xml) const
       {
       qDebug("FretDiagram::writeMusicXML() this %p harmony %p", this, _harmony);
-            xml.stag("frame");
-            xml.tag("frame-strings", strings());
-            xml.tag("frame-frets", frets());
-            QString strDots = "'";
-            QString strMarker = "'";
-            QString strFingering = "'";
-            for (int i = 0; i < strings(); ++i) {
-                  // TODO print frame note
-                  if (_dots) strDots += QString("%1'").arg(static_cast<int>(_dots[i]));
-                  if (_marker) strMarker += QString("%1'").arg(static_cast<int>(_marker[i]));
-                  if (_fingering) strFingering += QString("%1'").arg(static_cast<int>(_fingering[i]));
-                  if (_marker[i] != 88) {
-                        xml.stag("frame-note");
-                        xml.tag("string", strings() - i);
+      int _strings = strings();
+      xml.stag("frame");
+      xml.tag("frame-strings", _strings);
+      xml.tag("frame-frets", frets());
+      QString strDots = "'";
+      QString strMarker = "'";
+      QString strFingering = "'";
+      for (int i = 0; i < _strings; ++i) {
+            // TODO print frame note
+            if (_dots) strDots += QString("%1'").arg(static_cast<int>(_dots[i]));
+            if (_marker) strMarker += QString("%1'").arg(static_cast<int>(_marker[i]));
+            if (_fingering) strFingering += QString("%1'").arg(static_cast<int>(_fingering[i]));
+            if (_marker[i] != 88) {
+                  xml.stag("frame-note");
+                  xml.tag("string", _strings - i);
+                  if (_dots)
                         xml.tag("fret", _dots[i]);
-                        xml.etag();
+                  else
+                        xml.tag("fret", "0");
+                  xml.etag();
                   }
             }
-            qDebug("FretDiagram::writeMusicXML() this %p dots %s marker %s fingering %s",
-                   this, qPrintable(strDots), qPrintable(strMarker), qPrintable(strFingering));
-            /*
-            xml.tag("root-step", tpc2stepName(rootTpc));
-            int alter = tpc2alter(rootTpc);
-            if (alter)
-                  xml.tag("root-alter", alter);
-            */
-            xml.etag();
+      qDebug("FretDiagram::writeMusicXML() this %p dots %s marker %s fingering %s",
+             this, qPrintable(strDots), qPrintable(strMarker), qPrintable(strFingering));
+      /*
+      xml.tag("root-step", tpc2stepName(rootTpc));
+      int alter = tpc2alter(rootTpc);
+      if (alter)
+            xml.tag("root-alter", alter);
+      */
+      xml.etag();
       }
 
+#ifdef SCRIPT_INTERFACE
+
+//---------------------------------------------------------
+//   undoSetUserMag
+//---------------------------------------------------------
+
+void FretDiagram::undoSetUserMag(qreal val)
+      {
+      score()->undoChangeProperty(this, P_ID::MAG, val);
+      }
+
+//---------------------------------------------------------
+//   undoSetStrings
+//---------------------------------------------------------
+
+void FretDiagram::undoSetStrings(int val)
+      {
+      score()->undoChangeProperty(this, P_ID::FRET_STRINGS, val);
+      }
+
+//---------------------------------------------------------
+//   undoSetFrets
+//---------------------------------------------------------
+
+void FretDiagram::undoSetFrets(int val)
+      {
+      score()->undoChangeProperty(this, P_ID::FRET_FRETS, val);
+      }
+
+//---------------------------------------------------------
+//   undoSetBarre
+//---------------------------------------------------------
+
+void FretDiagram::undoSetBarre(int val)
+      {
+      score()->undoChangeProperty(this, P_ID::FRET_BARRE, val);
+      }
+
+//---------------------------------------------------------
+//   undoSetFretOffset
+//---------------------------------------------------------
+
+void FretDiagram::undoSetFretOffset(int val)
+      {
+      score()->undoChangeProperty(this, P_ID::FRET_OFFSET, val);
+      }
+
+#endif // SCRIPT_INTERFACE
+
 //---------------------------------------------------------
 //   getProperty
 //---------------------------------------------------------
@@ -618,6 +720,10 @@ QVariant FretDiagram::getProperty(P_ID propertyId) const
       {
       switch (propertyId) {
             case P_ID::MAG:            return userMag();
+            case P_ID::FRET_STRINGS:         return strings();
+            case P_ID::FRET_FRETS:           return frets();
+            case P_ID::FRET_BARRE:           return barre();
+            case P_ID::FRET_OFFSET:          return fretOffset();
             default:
                   return Element::getProperty(propertyId);
             }
@@ -631,6 +737,10 @@ QVariant FretDiagram::propertyDefault(P_ID propertyId) const
       {
       switch (propertyId) {
             case P_ID::MAG:            return 1.0;
+            case P_ID::FRET_STRINGS:         return DEFAULT_STRINGS;
+            case P_ID::FRET_FRETS:           return DEFAULT_FRETS;
+            case P_ID::FRET_BARRE:           return 0;
+            case P_ID::FRET_OFFSET:          return 0;
             default:
                   return Element::propertyDefault(propertyId);
             }
@@ -646,9 +756,22 @@ bool FretDiagram::setProperty(P_ID propertyId, const QVariant& v)
             case P_ID::MAG:
                   setUserMag(v.toDouble());
                   break;
+            case P_ID::FRET_STRINGS:
+                  setStrings(v.toInt());
+                  break;
+            case P_ID::FRET_FRETS:
+                  setFrets(v.toInt());
+                  break;
+            case P_ID::FRET_BARRE:
+                  setBarre(v.toInt());
+                  break;
+            case P_ID::FRET_OFFSET:
+                  setOffset(v.toInt());
+                  break;
             default:
                   return Element::setProperty(propertyId, v);
             }
+      score()->setLayoutAll(true);
       return true;
       }
 
