@@ -73,14 +73,14 @@ static void transposeChord(Chord* c, Interval srcTranspose)
 //    return false if paste fails
 //---------------------------------------------------------
 
-bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
+PasteStatus Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
       {
       Q_ASSERT(dst->segmentType() == Segment::Type::ChordRest);
       QList<Chord*> graceNotes;
       int dstTick = dst->tick();
       bool done = false;
       bool pasted = false;
-      int tickLen, staves = 0;
+      int tickLen = 0, staves = 0;
       while (e.readNextStartElement()) {
             if (done)
                   break;
@@ -156,6 +156,11 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
                               tuplet->setTrack(e.track());
                               tuplet->read(e);
                               int tick = e.tick();
+                              // no paste into local time signature
+                              if (staff(dstStaffIdx)->isLocalTimeSignature(tick)) {
+                                    qDebug("paste into local time signature");
+                                    return PasteStatus::DEST_LOCAL_TIME_SIGNATURE;
+                                    }
                               Measure* measure = tick2measure(tick);
                               tuplet->setParent(measure);
                               tuplet->setTick(tick);
@@ -164,7 +169,7 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
                               if (rticks < ticks) {
                                     qDebug("tuplet does not fit in measure");
                                     delete tuplet;
-                                    return false;
+                                    return PasteStatus::TUPLET_CROSSES_BAR;
                                     }
                               e.addTuplet(tuplet);
                               }
@@ -174,6 +179,11 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
                               cr->read(e);
                               cr->setSelected(false);
                               int tick = e.tick();
+                              // no paste into local time signature
+                              if (staff(dstStaffIdx)->isLocalTimeSignature(tick)) {
+                                    qDebug("paste into local time signature");
+                                    return PasteStatus::DEST_LOCAL_TIME_SIGNATURE;;
+                                    }
                               if (cr->isGrace())
                                     graceNotes.push_back(static_cast<Chord*>(cr));
                               else {
@@ -189,7 +199,7 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
                                                 int rticks = m->endTick() - tick;
                                                 if (rticks < ticks || (rticks != ticks && rticks < ticks * 2)) {
                                                       qDebug("tremolo does not fit in measure");
-                                                      return false;
+                                                      return PasteStatus::DEST_TREMOLO;
                                                       }
                                                 }
                                           for (int i = 0; i < graceNotes.size(); ++i) {
@@ -265,6 +275,13 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
                               sp->read(e);
                               sp->setTrack(e.track());
                               sp->setTick(e.tick());
+                              // check if we saw endSpanner / stop element already
+                              int id = e.spannerId(sp);
+                              const SpannerValues* sv = e.spannerValues(id);
+                              if (sv) {
+                                    sp->setTick2(sv->tick2);
+                                    sp->setTrack2(sv->track2);
+                                    }
                               undoAddElement(sp);
                               }
                         else if (tag == "endSpanner") {
@@ -397,8 +414,10 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
             s->connectTies();
 
       if (pasted) {                       //select only if we pasted something
-            Segment* s1 = tick2segment(dstTick);
-            Segment* s2 = tick2segment(dstTick + tickLen);
+            if (styleB(StyleIdx::createMultiMeasureRests))
+                  createMMRests();
+            Segment* s1 = tick2segmentMM(dstTick);
+            Segment* s2 = tick2segmentMM(dstTick + tickLen);
             int endStaff = dstStaff + staves;
             if (endStaff > nstaves())
                   endStaff = nstaves();
@@ -428,7 +447,7 @@ bool Score::pasteStaff(XmlReader& e, Segment* dst, int dstStaff)
             if (!selection().isRange())
                   _selection.setState(SelState::RANGE);
             }
-      return true;
+      return PasteStatus::PS_NO_ERROR;
       }
 
 //---------------------------------------------------------
@@ -577,6 +596,7 @@ void Score::pasteSymbols(XmlReader& e, ChordRest* dst)
       int   startTick   = dst->tick();    // the initial tick and track where to start pasting
       int   startTrack  = dst->track();
       int   maxTrack    = ntracks();
+      int   lastTick    = lastSegment()->tick();
 
       while (e.readNextStartElement()) {
             if (done)
@@ -614,12 +634,15 @@ void Score::pasteSymbols(XmlReader& e, ChordRest* dst)
                                           harmSegm = harmSegm->nextCR())
                                     ;
                               // if destTick overshot, no dest. segment: create one
-                              if (!harmSegm || harmSegm->tick() > destTick) {
+                              if (destTick >= lastTick) {
+                                    harmSegm = nullptr;
+                                    }
+                              else if (!harmSegm || harmSegm->tick() > destTick) {
                                     Measure* meas     = tick2measure(destTick);
-                                    harmSegm          = meas->getSegment(Segment::Type::ChordRest, destTick);
+                                    harmSegm          = meas ? meas->undoGetSegment(Segment::Type::ChordRest, destTick) : nullptr;
                               }
-                              if (destTrack >= maxTrack) {
-                                    qDebug("PasteSymbols: no track for %s", tag.toUtf8().data());
+                              if (destTrack >= maxTrack || harmSegm == nullptr) {
+                                    qDebug("PasteSymbols: no track or segment for %s", tag.toUtf8().data());
                                     e.skipCurrentElement();       // ignore
                                     continue;
                                     }
@@ -859,9 +882,10 @@ PasteStatus Score::cmdPaste(const QMimeData* ms, MuseScoreView* view)
                         qDebug("paste <%s>", data.data());
                   XmlReader e(data);
                   e.setPasteMode(true);
-                  if (!pasteStaff(e, cr->segment(),cr->staffIdx())) {
+                  PasteStatus ps = pasteStaff(e, cr->segment(), cr->staffIdx());
+                  if (ps != PasteStatus::PS_NO_ERROR) {
                         qDebug("paste failed");
-                        return PasteStatus::TUPLET_CROSSES_BAR;
+                        return ps;
                         }
                   }
             }
