@@ -16,6 +16,7 @@
 #include "groups.h"
 #include "xml.h"
 #include "note.h"
+#include "barline.h"
 
 namespace Ms {
 
@@ -135,6 +136,7 @@ static const PropertyData propertyList[] = {
       { P_ID::NUMBERS_ONLY,        false, "numbersOnly",   P_TYPE::BOOL   },
       { P_ID::TRILL_TYPE,          false, "",              P_TYPE::INT    },
 
+      { P_ID::HAIRPIN_TEXTLINE,    false, "useTextLine",   P_TYPE::BOOL   },
       { P_ID::HAIRPIN_CIRCLEDTIP,  false, "hairpinCircledTip", P_TYPE::BOOL     },
       { P_ID::HAIRPIN_TYPE,        true,  "",              P_TYPE::INT     },
       { P_ID::HAIRPIN_HEIGHT,      false, "hairpinHeight",     P_TYPE::SPATIUM },
@@ -213,7 +215,7 @@ static const PropertyData propertyList[] = {
       { P_ID::VOLTA_ENDING,        true,  "endings",               P_TYPE::INT_LIST },
       { P_ID::LINE_VISIBLE,        true,  "lineVisible",           P_TYPE::BOOL },
 
-      { P_ID::SYSTEM_INITIAL_BARLINE_TYPE, false, "sysInitBarLineType", P_TYPE::INT },
+      { P_ID::SYSTEM_INITIAL_BARLINE_TYPE, false, "sysInitBarLineType", P_TYPE::BARLINE_TYPE },
       { P_ID::MAG,                 false, "mag",                   P_TYPE::REAL },
       { P_ID::USE_DRUMSET,         false, "useDrumset",            P_TYPE::BOOL },
       { P_ID::PART_VOLUME,         false, "volume",                P_TYPE::INT },
@@ -228,6 +230,14 @@ static const PropertyData propertyList[] = {
       { P_ID::TRACK,               false, 0,                       P_TYPE::INT },
 
       { P_ID::GLISSANDO_STYLE,     false, "glissandoStyle",        P_TYPE::GLISSANDO_STYLE},
+
+      { P_ID::LAYOUT_MODE,         false, 0,                       P_TYPE::INT },
+
+      { P_ID::FRET_STRINGS,        false, "strings",               P_TYPE::INT },
+      { P_ID::FRET_FRETS,          false, "frets",                 P_TYPE::INT },
+      { P_ID::FRET_BARRE,          false, "barre",                 P_TYPE::INT },
+      { P_ID::FRET_OFFSET,         false, "fretOffset",            P_TYPE::INT },
+
       { P_ID::END,                 false, "",                      P_TYPE::INT }
       };
 
@@ -307,7 +317,7 @@ QVariant getProperty(P_ID id, XmlReader& e)
                       QString value(e.readElementText());
                       if ( value == "baroque")
                           return QVariant(int(MScore::OrnamentStyle::BAROQUE));
-                      
+
                       return QVariant(int(MScore::OrnamentStyle::DEFAULT));
                   }
                   break; // break is really not necessary because of the default return
@@ -360,6 +370,25 @@ QVariant getProperty(P_ID id, XmlReader& e)
                         return QVariant(int(Element::Placement::BELOW));
                   }
                   break;
+            case P_TYPE::BARLINE_TYPE: {
+                  bool ok;
+                  const QString& val(e.readElementText());
+                  // In MuseScore 2.0.2 and before, SYSTEM_INITIAL_BARLINE_TYPE
+                  // was stored as a int, so try this first
+                  int ct = val.toInt(&ok);
+                  if (ok)
+                        return QVariant(ct);
+                  else {
+                        for (unsigned i = 0; i < BarLine::barLineTableSize(); ++i) {
+                              if (BarLine::barLineTypeName(BarLineType(i)) == val) {
+                                    ct = i;
+                                    break;
+                                    }
+                              }
+                        return QVariant(ct);
+                        }
+                  }
+                  break;
             case P_TYPE::BEAM_MODE:             // TODO
                   return QVariant(int(0));
 
