@@ -120,7 +120,7 @@ enum class Pad : char {
 
 //---------------------------------------------------------
 //   LayoutMode
-//    PAGE   The normal page view, honors page and line breaks
+//    PAGE   The normal page view, honors page and line breaks.
 //    LINE   The panoramic view, one long system
 //    FLOAT  The "reflow" mode, ignore page and line breaks
 //    SYSTEM The "never ending page", page break are turned into line break
@@ -162,8 +162,8 @@ class MeasureBaseList {
 struct MidiMapping {
       Part* part;
       Channel* articulation;
-      char port;
-      char channel;
+      signed char port;
+      signed char channel;
       };
 
 //---------------------------------------------------------
@@ -224,7 +224,9 @@ enum class PasteStatus : char {
       NO_DEST,
       DEST_TUPLET,
       DEST_NO_CR,
-      TUPLET_CROSSES_BAR
+      TUPLET_CROSSES_BAR,
+      DEST_LOCAL_TIME_SIGNATURE,
+      DEST_TREMOLO
       };
 
 //---------------------------------------------------------
@@ -255,7 +257,7 @@ enum class PasteStatus : char {
 //   @P title           string            title of the score (read only)
 //---------------------------------------------------------
 
-class Score : public QObject {
+class Score : public QObject, public ScoreElement {
       Q_OBJECT
       Q_PROPERTY(QString                        composer          READ composer)
       Q_PROPERTY(int                            duration          READ duration)
@@ -781,7 +783,7 @@ class Score : public QObject {
       void spatiumChanged(qreal oldValue, qreal newValue);
 
       PasteStatus cmdPaste(const QMimeData* ms, MuseScoreView* view);
-      bool pasteStaff(XmlReader&, Segment* dst, int staffIdx);
+      PasteStatus pasteStaff(XmlReader&, Segment* dst, int staffIdx);
       void pasteSymbols(XmlReader& e, ChordRest* dst);
       void renderMidi(EventMap* events);
       void renderStaff(EventMap* events, Staff*);
@@ -844,6 +846,7 @@ class Score : public QObject {
 
       void endUndoRedo();
       Measure* searchLabel(const QString& s);
+      Measure* searchLabelWithinSectionFirst(const QString& s, Measure* sectionStartMeasure, Measure* sectionEndMeasure);
       RepeatList* repeatList() const;
       qreal utick2utime(int tick) const;
       int utime2utick(qreal utime) const;
@@ -875,8 +878,9 @@ class Score : public QObject {
       Ms::Measure* lastMeasureMM() const;
       MeasureBase* measure(int idx) const;
 
+      Ms::Segment* firstSegment(Segment::Type s) const;
       //@ returns the first segment of the score of the given type (use Segment.Clef, ... enum)
-      Q_INVOKABLE Ms::Segment* firstSegment(Segment::Type s = Segment::Type::All) const;
+      Q_INVOKABLE Ms::Segment* firstSegment(int segType = static_cast<int>(Segment::Type::All)) const;
       Ms::Segment* firstSegmentMM(Segment::Type s = Segment::Type::All) const;
       Ms::Segment* lastSegment() const;
 
@@ -988,7 +992,7 @@ class Score : public QObject {
       void setSoloMute();
 
       LayoutMode layoutMode() const         { return _layoutMode; }
-      void setLayoutMode(LayoutMode lm);
+      void setLayoutMode(LayoutMode lm)     { _layoutMode = lm;   }
 
       void doLayoutSystems();
       void doLayoutPages();
@@ -1039,7 +1043,7 @@ class Score : public QObject {
       Hairpin* addHairpin(bool crescendo, int tickStart, int tickEnd, int track);
 
       ChordRest* findCR(int tick, int track) const;
-      ChordRest* findCRinStaff(int tick, int track) const;
+      ChordRest* findCRinStaff(int tick, int staffIdx) const;
       void layoutSpanner();
       void insertTime(int tickPos, int tickLen);
 
@@ -1097,6 +1101,12 @@ class Score : public QObject {
       bool checkKeys();
       bool checkClefs();
 
+      void switchToPageMode();
+
+      virtual QVariant getProperty(P_ID) const override;
+      virtual bool setProperty(P_ID, const QVariant&) override;
+      virtual QVariant propertyDefault(P_ID) const override;
+
       friend class ChangeSynthesizerState;
       friend class Chord;
       };
