@@ -35,10 +35,12 @@
 #include "mscore.h"
 #include "stafftype.h"
 #include "sym.h"
+
 #ifdef OMR
 #include "omr/omr.h"
 #include "omr/omrpage.h"
 #endif
+
 #include "sig.h"
 #include "undo.h"
 #include "imageStore.h"
@@ -351,26 +353,6 @@ bool Score::saveFile()
             MScore::lastError = tr("The following file is locked: \n%1 \n\nTry saving to a different location.").arg(info.filePath());
             return false;
             }
-
-      // if file was already saved in this session
-      // save but don't overwrite backup again
-
-      if (saved()) {
-            try {
-                  if (suffix == "mscx")
-                        saveFile(info);
-                  else
-                        saveCompressedFile(info, false);
-                  }
-            catch (QString s) {
-                  MScore::lastError = s;
-                  return false;
-                  }
-            undo()->setClean();
-            info.refresh();
-            update();
-            return true;
-            }
       //
       // step 1
       // save into temporary file to prevent partially overwriting
@@ -400,38 +382,54 @@ bool Score::saveFile()
             }
       temp.close();
 
-      //
-      // step 2
-      // remove old backup file if exists
-      //
+      QString name(info.filePath());
       QDir dir(info.path());
-      QString backupName = QString(".") + info.fileName() + QString(",");
-      if (dir.exists(backupName)) {
-            if (!dir.remove(backupName)) {
-//                  if (!MScore::noGui)
-//                        QMessageBox::critical(0, tr("MuseScore: Save File"),
-//                           tr("Removing old backup file ") + backupName + tr(" failed"));
+      if (!saved()) {
+            // if file was already saved in this session
+            // save but don't overwrite backup again
+
+            //
+            // step 2
+            // remove old backup file if exists
+            //
+            QString backupName = QString(".") + info.fileName() + QString(",");
+            if (dir.exists(backupName)) {
+                  if (!dir.remove(backupName)) {
+//                      if (!MScore::noGui)
+//                            QMessageBox::critical(0, tr("MuseScore: Save File"),
+//                               tr("Removing old backup file ") + backupName + tr(" failed"));
+                        }
+                  }
+
+            //
+            // step 3
+            // rename old file into backup
+            //
+            if (dir.exists(name)) {
+                  if (!dir.rename(name, backupName)) {
+//                      if (!MScore::noGui)
+//                            QMessageBox::critical(0, tr("MuseScore: Save File"),
+//                               tr("Renaming old file <")
+//                               + name + tr("> to backup <") + backupName + tr("> failed"));
+                        }
+                  }
+#ifdef Q_OS_WIN
+            QFileInfo fileBackup(dir, backupName);
+            QString backupNativePath = QDir::toNativeSeparators(fileBackup.absoluteFilePath());
+            SetFileAttributes((LPCTSTR)backupNativePath.toLocal8Bit(), FILE_ATTRIBUTE_HIDDEN);
+#endif
+            }
+      else {
+            // file has previously been saved - remove the old file
+            if (dir.exists(name)) {
+                  if (!dir.remove(name)) {
+//                      if (!MScore::noGui)
+//                            QMessageBox::critical(0, tr("MuseScore: Save File"),
+//                               tr("Removing old file") + name + tr(" failed"));
+                        }
                   }
             }
 
-      //
-      // step 3
-      // rename old file into backup
-      //
-      QString name(info.filePath());
-      if (dir.exists(name)) {
-            if (!dir.rename(name, backupName)) {
-//                  if (!MScore::noGui)
-//                        QMessageBox::critical(0, tr("MuseScore: Save File"),
-//                           tr("Renaming old file <")
-//                            + name + tr("> to backup <") + backupName + tr("> failed"));
-                  }
-            }
-#ifdef Q_OS_WIN
-      QFileInfo fileBackup(dir, backupName);
-      QString backupNativePath = QDir::toNativeSeparators(fileBackup.absoluteFilePath());
-      SetFileAttributes((LPCTSTR)backupNativePath.toLocal8Bit(), FILE_ATTRIBUTE_HIDDEN);
-#endif
       //
       // step 4
       // rename temp name into file name
@@ -474,11 +472,7 @@ void Score::saveCompressedFile(QFileInfo& info, bool onlySelection)
 QImage Score::createThumbnail()
       {
       LayoutMode layoutMode = _layoutMode;
-      if (layoutMode != LayoutMode::PAGE) {
-            startCmd();
-            undo(new ChangeLayoutMode(this, LayoutMode::PAGE));
-            doLayout();
-            }
+      switchToPageMode();
       Page* page = pages().at(0);
       QRectF fr  = page->abbox();
       qreal mag  = 256.0 / qMax(fr.width(), fr.height());
@@ -1056,7 +1050,7 @@ bool Score::read(XmlReader& e)
             else if (tag == "Synthesizer")
                   _synthesizerState.read(e);
             else if (tag == "Spatium")
-                  _style.setSpatium (e.readDouble() * MScore::DPMM); // obsolete, moved to Style
+                  _style.setSpatium (e.readDouble() * DPMM); // obsolete, moved to Style
             else if (tag == "page-offset")            // obsolete, moved to Score
                   setPageNumberOffset(e.readInt());
             else if (tag == "Division")
@@ -1367,6 +1361,18 @@ void Score::writeSegments(Xml& xml, int strack, int etrack,
    Segment* fs, Segment* ls, bool writeSystemElements, bool clip, bool needFirstTick)
       {
       int endTick = ls == 0 ? lastMeasure()->endTick() : ls->tick();
+      // in clipboard mode, ls might be in an mmrest
+      // since we are traversing regular measures,
+      // force ls to last segment of the corresponding regular measure
+      // if it is not in same measure as fs
+      Measure* lm = ls ? ls->measure() : 0;
+      if (clip && lm && lm->isMMRest() && lm != fs->measure()) {
+            lm = tick2measure(ls->measure()->tick());
+            if (lm)
+                  ls = lm->last();
+            else
+                  qDebug("writeSegments: no measure for end segment in mmrest");
+            }
       for (int track = strack; track < etrack; ++track) {
             if (!xml.canWriteVoice(track))
                   continue;
@@ -1394,7 +1400,7 @@ void Score::writeSegments(Xml& xml, int strack, int etrack,
                                     }
                               }
                         }
-                  foreach (Element* e, segment->annotations()) {
+                  for (Element* e : segment->annotations()) {
                         if (e->track() != track || e->generated()
                            || (e->systemFlag() && !writeSystemElements)) {
                               continue;
