@@ -513,7 +513,7 @@ void Staff::write(Xml& xml) const
                   xml.tag("barLineSpan", _barLineSpan);
             }
       if (_userDist != 0.0)
-            xml.tag("distOffset", _userDist / spatium());
+            xml.tag("distOffset", _userDist / score()->spatium());
 
       writeProperty(xml, P_ID::MAG);
       writeProperty(xml, P_ID::COLOR);
@@ -598,7 +598,7 @@ void Staff::read(XmlReader& e)
                         _barLineTo = lines() == 1 ? BARLINE_SPAN_1LINESTAFF_TO : (lines() - 1) * 2;
                   }
             else if (tag == "distOffset")
-                  _userDist = e.readDouble() * spatium();
+                  _userDist = e.readDouble() * score()->spatium();
             else if (tag == "mag")
                   _userMag = e.readDouble(0.1, 10.0);
             else if (tag == "linkedTo") {
@@ -780,7 +780,8 @@ void Staff::unlink(Staff* staff)
       {
       if (!_linkedStaves)
             return;
-      Q_ASSERT(_linkedStaves->staves().contains(staff));
+      if (!_linkedStaves->staves().contains(staff))
+            return;
       _linkedStaves->remove(staff);
       if (_linkedStaves->staves().size() <= 1) {
             delete _linkedStaves;
@@ -795,7 +796,8 @@ void Staff::unlink(Staff* staff)
 
 void LinkedStaves::add(Staff* staff)
       {
-      _staves.append(staff);
+      if (!_staves.contains(staff))
+            _staves.append(staff);
       }
 
 //---------------------------------------------------------
@@ -1128,7 +1130,7 @@ QVariant Staff::getProperty(P_ID id) const
             case P_ID::SMALL:
                   return small();
             default:
-                  qDebug("Staff::setProperty: unhandled id");
+                  qDebug("Staff::getProperty: unhandled id");
                   return QVariant();
             }
       }
