@@ -634,6 +634,8 @@ int System::y2staff(qreal y) const
 
 void System::add(Element* el)
       {
+      if (!el)
+            return;
 // qDebug("%p System::add: %p %s", this, el, el->name());
 
       el->setParent(this);
@@ -1000,10 +1002,8 @@ qDebug("Lyrics: melisma end segment not implemented");
       // convert font size to raster units, scaling if spatium-dependent
       qreal size = ts.size();
       if (ts.sizeIsSpatiumDependent())
-            size *= _spatium / (SPATIUM20 * PPI);     // <= (MScore::DPI / PPI) * (_spatium / (SPATIUM20 * Mscore::DPI))
-      else
-            size *= MScore::DPI / PPI;
-      qreal y = -size * staffMag * 0.30;              // TODO: make this a style parameter (for now, a conventional percentage of the whole font height)
+            size *= _spatium / SPATIUM20;
+      qreal y = -size * staffMag * 0.30;        // TODO: make this a style parameter (for now, a conventional percentage of the whole font height)
 
       qreal x1 = x + l->pagePos().x();
       qreal x2 = nl->bbox().left() + nl->pagePos().x();
@@ -1108,6 +1108,16 @@ qreal System::staffYpage(int staffIdx) const
       return _staves[staffIdx]->y() + y(); // pagePos().y();
       }
 
+//---------------------------------------------------------
+//   staffCanvasYpage
+//    return canvas coordinates
+//---------------------------------------------------------
+
+qreal System::staffCanvasYpage(int staffIdx) const
+      {
+      return _staves[staffIdx]->y() + y() + page()->canvasPos().y();
+      }
+
 //---------------------------------------------------------
 //   write
 //---------------------------------------------------------
