@@ -555,7 +555,7 @@ struct Verse {
       };
 
 struct CNote {
-      char pitch;
+      signed char pitch;
       int explAlteration;     // 1 force, 2 suppress
       int headType;
       int alteration;
@@ -570,7 +570,7 @@ class ChordObj : public BasicDurationalObj, public NoteObj {
    public:
       enum class StemDir : signed char { DOWN = -1, AUTO = 0, UP = 1, NONE = 3 };
       BeamMode beamMode;
-      char notationStave;
+      signed char notationStave;
       char dStemLength;
       unsigned char nTremoloBars;
       unsigned articulation;
