@@ -176,6 +176,8 @@ Debugger::Debugger(QWidget* parent)
 
 void Debugger::selectElement()
       {
+      if (!curElement)
+            return;
       curElement->score()->select(curElement);
       }
 
@@ -185,6 +187,8 @@ void Debugger::selectElement()
 
 void Debugger::resetElement()
       {
+      if (!curElement)
+            return;
       curElement->reset();
       layout();
       }
@@ -195,6 +199,8 @@ void Debugger::resetElement()
 
 void Debugger::layout()
       {
+      if (!curElement)
+            return;
       curElement->score()->doLayout();
       curElement->score()->end();
       mscore->endCmd();
@@ -860,9 +866,7 @@ void SegmentView::setElement(Element* e)
       sb.spannerBack->clear();
       sb.annotations->clear();
       foreach(Element* sp, s->annotations()) {
-            QString s;
-            s.setNum(qptrdiff(sp), 16);
-            QListWidgetItem* item = new QListWidgetItem(s);
+            QListWidgetItem* item = new QListWidgetItem(QString("%1 %2").arg(qptrdiff(sp), 8, 16).arg(sp->name()));
             item->setData(Qt::UserRole, QVariant::fromValue<void*>((void*)sp));
             sb.annotations->addItem(item);
             }
