@@ -65,7 +65,7 @@ bool MP3Exporter::findLibrary()
       if (!mLibPath.isEmpty()) {
             QFileInfo fi(mLibPath);
             path = fi.absolutePath();
-            name = fi.baseName();
+            name = fi.completeBaseName();
             }
       else {
             path = getLibraryPath();
@@ -531,7 +531,7 @@ void MP3Exporter::cancelEncoding()
       else if (beWriteInfoTag) {
          f.flush();
          QFileInfo fi(f);
-         beWriteInfoTag(mGF, qPrintable(fi.baseName()));
+         beWriteInfoTag(mGF, qPrintable(fi.completeBaseName()));
          mGF = NULL;
       }
 #endif
@@ -694,7 +694,9 @@ bool MuseScore::saveMp3(Score* score, const QString& name)
       QProgressDialog progress(this);
       progress.setWindowFlags(Qt::WindowFlags(Qt::Dialog | Qt::FramelessWindowHint | Qt::WindowTitleHint));
       progress.setWindowModality(Qt::ApplicationModal);
-      progress.setCancelButton(0);
+      //progress.setCancelButton(0);
+      progress.setCancelButtonText(tr("Cancel"));
+      progress.setLabelText(tr("Exporting..."));
       if (!MScore::noGui)
             progress.show();
 
@@ -707,6 +709,7 @@ bool MuseScore::saveMp3(Score* score, const QString& name)
       EventMap::const_iterator endPos = events.cend();
       --endPos;
       const int et = (score->utick2utime(endPos->first) + 1) * MScore::sampleRate;
+      const int maxEndTime = (score->utick2utime(endPos->first) + 3) * MScore::sampleRate;
       progress.setRange(0, et);
 
       for (int pass = 0; pass < 2; ++pass) {
@@ -822,6 +825,8 @@ bool MuseScore::saveMp3(Score* score, const QString& name)
                         }
                   playTime = endTime;
                   if (!MScore::noGui) {
+                        if (progress.wasCanceled())
+                              break;
                         progress.setValue((pass * et + playTime) / 2);
                         qApp->processEvents();
                         }
@@ -830,7 +835,12 @@ bool MuseScore::saveMp3(Score* score, const QString& name)
                   // create sound until the sound decays
                   if (playTime >= et && max * peak < 0.000001)
                         break;
+                  // hard limit
+                  if (playTime > maxEndTime)
+                        break;
                   }
+            if (progress.wasCanceled())
+                  break;
             if (pass == 0 && peak == 0.0) {
                   qDebug("song is empty");
                   break;
@@ -842,10 +852,13 @@ bool MuseScore::saveMp3(Score* score, const QString& name)
       if (bytes > 0L)
             file.write((char*)bufferOut, bytes);
 
+      bool wasCanceled = progress.wasCanceled();
       progress.close();
       delete synti;
       delete[] bufferOut;
       file.close();
+      if (wasCanceled)
+            file.remove();
       MScore::sampleRate = oldSampleRate;
       return true;
       }
