@@ -158,7 +158,7 @@ void ChordStyleEditor::setChordList(ChordList* cl)
             paletteTab->addTab(accPalette, f.family);
             QFont qf(f.family);
             qf.setStyleStrategy(QFont::NoFontMerging);
-            int size = lrint(20.0 * MScore::DPI / PPI);
+            int size = lrint(20.0 * DPI / PPI);
             qf.setPixelSize(size);
 
             QFontMetricsF fi(qf);
@@ -250,7 +250,7 @@ void HarmonyCanvas::paintEvent(QPaintEvent* event)
 
       qreal spatium = gscore->spatium();
       qreal mag = PALETTE_SPATIUM * extraMag / spatium;
-      spatium = SPATIUM20 * MScore::DPI;
+      spatium = SPATIUM20;
 
       QPainter p(this);
 
