@@ -265,7 +265,7 @@ void MTrack::processMeta(int tick, const MidiEvent& mm)
             qDebug("processMeta: no staff");
             return;
             }
-      const uchar* data = (uchar*)mm.edata();
+      const uchar* data = mm.edata();
       Score* cs         = staff->score();
 
       switch (mm.metaType()) {
@@ -290,7 +290,7 @@ void MTrack::processMeta(int tick, const MidiEvent& mm)
                   break;
             case META_KEY_SIGNATURE:
                   {
-                  const int key = ((const char*)data)[0];
+                  const signed char key = ((const signed char*)data)[0];
                   if (key < -7 || key > 7) {
                         qDebug("ImportMidi: illegal key %d", key);
                         break;
