@@ -31,6 +31,7 @@
 #include "inspectorText.h"
 #include "musescore.h"
 #include "scoreview.h"
+#include "bendproperties.h"
 
 #include "libmscore/element.h"
 #include "libmscore/score.h"
@@ -51,6 +52,8 @@
 #include "libmscore/staff.h"
 #include "libmscore/measure.h"
 #include "libmscore/tuplet.h"
+#include "libmscore/bend.h"
+#include "libmscore/tremolobar.h"
 
 namespace Ms {
 
@@ -66,11 +69,10 @@ void MuseScore::showInspector(bool visible)
             connect(_inspector, SIGNAL(visibilityChanged(bool)), a, SLOT(setChecked(bool)));
             addDockWidget(Qt::RightDockWidgetArea, _inspector);
             }
-      if (visible) {
-            updateInspector();
-            }
       if (_inspector)
             _inspector->setVisible(visible);
+      if (visible)
+            updateInspector();
       }
 
 //---------------------------------------------------------
@@ -240,7 +242,7 @@ void Inspector::setElements(const QList<Element*>& l)
                               ie = new InspectorAmbitus(this);
                               break;
                         case Element::Type::FRET_DIAGRAM:
-                              ie = new InspectorFret(this);
+                              ie = new InspectorFretDiagram(this);
                               break;
                         case Element::Type::LAYOUT_BREAK:
                               ie = new InspectorBreak(this);
@@ -248,14 +250,25 @@ void Inspector::setElements(const QList<Element*>& l)
                         case Element::Type::BEND:
                               ie = new InspectorBend(this);
                               break;
+                        case Element::Type::TREMOLOBAR:
+                              ie = new InspectorTremoloBar(this);
+                              break;
                         case Element::Type::ARPEGGIO:
                               ie = new InspectorArpeggio(this);
                               break;
                         default:
-                              if (_element->isText())
-                                    ie = new InspectorText(this);
-                              else
-                                    ie = new InspectorElement(this);
+                              if (_element->isText()) {
+                                    if (_element->type() == Element::Type::INSTRUMENT_NAME) // these are generated
+                                          ie = new InspectorEmpty(this);
+                                    else
+                                          ie = new InspectorText(this);
+                                    }
+                              else {
+                                    if (_element->type() == Element::Type::BRACKET) // these are generated
+                                          ie = new InspectorEmpty(this);
+                                    else
+                                          ie = new InspectorElement(this);
+                                    }
                               break;
                         }
                   }
@@ -654,6 +667,58 @@ InspectorBend::InspectorBend(QWidget* parent)
             };
 
       mapSignals();
+      connect(g.properties, SIGNAL(clicked()), SLOT(propertiesClicked()));
+      }
+
+//---------------------------------------------------------
+//   propertiesClicked
+//---------------------------------------------------------
+
+void InspectorBend::propertiesClicked()
+      {
+      Bend* b = static_cast<Bend*>(inspector->element());
+      Score* score = b->score();
+      score->startCmd();
+      mscore->currentScoreView()->editBendProperties(b);
+      score->setLayoutAll(true);
+      score->endCmd();
+      }
+
+//---------------------------------------------------------
+//   InspectorTremoloBar
+//---------------------------------------------------------
+
+InspectorTremoloBar::InspectorTremoloBar(QWidget* parent)
+   : InspectorBase(parent)
+      {
+      e.setupUi(addWidget());
+      g.setupUi(addWidget());
+
+      iList = {
+            { P_ID::COLOR,        0, 0, e.color,       e.resetColor       },
+            { P_ID::VISIBLE,      0, 0, e.visible,     e.resetVisible     },
+            { P_ID::USER_OFF,     0, 0, e.offsetX,     e.resetX           },
+            { P_ID::USER_OFF,     1, 0, e.offsetY,     e.resetY           },
+//            { P_ID::PLAY,         0, 0, g.playBend,    g.resetPlayBend    }
+            { P_ID::MAG,          0, 0, g.mag,         g.resetMag        }
+            };
+
+      mapSignals();
+      connect(g.properties, SIGNAL(clicked()), SLOT(propertiesClicked()));
+      }
+
+//---------------------------------------------------------
+//   propertiesClicked
+//---------------------------------------------------------
+
+void InspectorTremoloBar::propertiesClicked()
+      {
+      Bend* b = static_cast<Bend*>(inspector->element());
+      Score* score = b->score();
+      score->startCmd();
+      mscore->currentScoreView()->editBendProperties(b);
+      score->setLayoutAll(true);
+      score->endCmd();
       }
 
 //---------------------------------------------------------
@@ -742,6 +807,7 @@ InspectorTempoText::InspectorTempoText(QWidget* parent)
             { P_ID::TEMPO_FOLLOW_TEXT, 0, 0, tt.followText, tt.resetFollowText }
             };
       mapSignals();
+      connect(t.resetToStyle, SIGNAL(clicked()), SLOT(resetToStyle()));
       connect(tt.followText, SIGNAL(toggled(bool)), tt.tempo, SLOT(setDisabled(bool)));
       }
 
@@ -799,6 +865,7 @@ InspectorDynamic::InspectorDynamic(QWidget* parent)
             { P_ID::VELOCITY,           0, 0, d.velocity, d.resetVelocity }
             };
       mapSignals();
+      connect(t.resetToStyle, SIGNAL(clicked()), SLOT(resetToStyle()));
       }
 
 //---------------------------------------------------------
@@ -833,11 +900,12 @@ InspectorSlur::InspectorSlur(QWidget* parent)
       s.setupUi(addWidget());
 
       iList = {
-            { P_ID::COLOR,      0, 0, e.color,    e.resetColor    },
-            { P_ID::VISIBLE,    0, 0, e.visible,  e.resetVisible  },
-            { P_ID::USER_OFF,   0, 0, e.offsetX,  e.resetX        },
-            { P_ID::USER_OFF,   1, 0, e.offsetY,  e.resetY        },
-            { P_ID::LINE_TYPE,  0, 0, s.lineType, s.resetLineType }
+            { P_ID::COLOR,           0, 0, e.color,         e.resetColor         },
+            { P_ID::VISIBLE,         0, 0, e.visible,       e.resetVisible       },
+            { P_ID::USER_OFF,        0, 0, e.offsetX,       e.resetX             },
+            { P_ID::USER_OFF,        1, 0, e.offsetY,       e.resetY             },
+            { P_ID::LINE_TYPE,       0, 0, s.lineType,      s.resetLineType      },
+            { P_ID::SLUR_DIRECTION,  0, 0, s.slurDirection, s.resetSlurDirection }
             };
       mapSignals();
       }
