@@ -371,6 +371,8 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       QStringList _recentScores;
       QToolButton* _playButton;
 
+      qreal _physicalDotsPerInch;
+
       //---------------------
 
       virtual void closeEvent(QCloseEvent*);
@@ -396,8 +398,6 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       void showInspector(bool);
       void showOmrPanel(bool);
       void showNavigator(bool);
-      void showMixer(bool);
-      void showSynthControl(bool);
       void showSelectionWindow(bool);
       void showSearchDialog();
       void splitWindow(bool horizontal);
@@ -422,6 +422,7 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       void cmd(QAction* a, const QString& cmd);
       void autoSaveTimerTimeout();
       void helpBrowser1() const;
+      void resetAndRestart();
       void about();
       void aboutQt();
       void aboutMusicXML();
@@ -435,8 +436,7 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       void seqStopped();
       void cmdAppendMeasures();
       void cmdInsertMeasures();
-      void magChanged(int);
-      void magTextChanged();
+      void magChanged(MagIdx);
       void showPageSettings();
       void removeTab(int);
       void removeTab();
@@ -563,6 +563,7 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       void setAdvancedPalette();
       void setBasicPalette();
       void excerptsChanged(Score*);
+      void scorePageLayoutChanged();
       bool processMidiRemote(MidiRemoteType type, int data);
       ScoreTab* getTab1() const { return tab1; }
       ScoreTab* getTab2() const { return tab2; }
@@ -692,6 +693,10 @@ class MuseScore : public QMainWindow, public MuseScoreCore {
       QHelpEngine*  helpEngine() const { return _helpEngine;   }
 
       void updateInspector();
+      void showSynthControl(bool);
+      void showMixer(bool);
+
+      qreal physicalDotsPerInch() const { return _physicalDotsPerInch; }
       };
 
 extern MuseScore* mscore;
