@@ -30,7 +30,6 @@
 #include "shortcutcapturedialog.h"
 #include "scoreview.h"
 #include "libmscore/sym.h"
-#include "palette.h"
 #include "pa.h"
 #include "pm.h"
 #include "libmscore/page.h"
@@ -53,29 +52,6 @@ extern bool externalStyle;
 
 static int exportAudioSampleRates[2] = { 44100, 48000 };
 
-//---------------------------------------------------------
-//   PeriodItem
-//---------------------------------------------------------
-
-struct PeriodItem {
-       int time;
-       const char* text;
-       PeriodItem(const int t, const  char* txt) {
-             time = t;
-             text = txt;
-             }
-       };
-
-static PeriodItem updatePeriods[] = {
-      PeriodItem(24,      QT_TRANSLATE_NOOP("preferences","Every Day")),
-      PeriodItem(72,      QT_TRANSLATE_NOOP("preferences","Every 3 Days")),
-      PeriodItem(7*24,    QT_TRANSLATE_NOOP("preferences","Every Week")),
-      PeriodItem(2*7*24,  QT_TRANSLATE_NOOP("preferences","Every 2 Weeks")),
-      PeriodItem(30*24,   QT_TRANSLATE_NOOP("preferences","Every Month")),
-      PeriodItem(2*30*24, QT_TRANSLATE_NOOP("preferences","Every 2 Months")),
-      PeriodItem(-1,      QT_TRANSLATE_NOOP("preferences","Never")),
-      };
-
 //---------------------------------------------------------
 //   Preferences
 //---------------------------------------------------------
@@ -99,6 +75,7 @@ void Preferences::init()
       bgWallpaper        = QString();
       fgWallpaper        = ":/data/paper5.png";
       fgColor.setNamedColor("#f9f9f9");
+      pianoHlColor.setNamedColor("#1259d0");
       iconHeight         = 24;
       iconWidth          = 28;
 
@@ -200,7 +177,7 @@ void Preferences::init()
       myImagesPath    = QFileInfo(QString("%1/%2").arg(wd).arg(QCoreApplication::translate("images_directory",     "Images"))).absoluteFilePath();
       myTemplatesPath = QFileInfo(QString("%1/%2").arg(wd).arg(QCoreApplication::translate("templates_directory",  "Templates"))).absoluteFilePath();
       myPluginsPath   = QFileInfo(QString("%1/%2").arg(wd).arg(QCoreApplication::translate("plugins_directory",    "Plugins"))).absoluteFilePath();
-      sfPath          = QString("%1;%2").arg(QFileInfo(QString("%1%2").arg(mscoreGlobalShare).arg("sound")).absoluteFilePath()).arg(QFileInfo(QString("%2/%3").arg(wd).arg(QCoreApplication::translate("soundfonts_directory", "Soundfonts"))).absoluteFilePath());
+      mySoundfontsPath = QFileInfo(QString("%1/%2").arg(wd).arg(QCoreApplication::translate("soundfonts_directory", "Soundfonts"))).absoluteFilePath();
 
       MScore::setNudgeStep(.1);         // cursor key (default 0.1)
       MScore::setNudgeStep10(1.0);      // Ctrl + cursor key (default 1.0)
@@ -245,6 +222,7 @@ void Preferences::write()
       s.setValue("selectColor4",       MScore::selectColor[3]);
       s.setValue("dropColor",          MScore::dropColor);
       s.setValue("defaultColor",       MScore::defaultColor);
+      s.setValue("pianoHlColor",       pianoHlColor);
       s.setValue("enableMidiInput",    enableMidiInput);
       s.setValue("playNotes",          playNotes);
       s.setValue("playChordOnAddNote", playChordOnAddNote);
@@ -312,7 +290,7 @@ void Preferences::write()
       s.setValue("paperHeight", MScore::defaultStyle()->pageFormat()->height());
 
       s.setValue("twosided",    MScore::defaultStyle()->pageFormat()->twosided());
-      s.setValue("spatium",     MScore::defaultStyle()->spatium() / MScore::DPI);
+      s.setValue("spatium",     MScore::defaultStyle()->spatium() / DPI);
 
       s.setValue("mag", mag);
 
@@ -335,7 +313,7 @@ void Preferences::write()
       s.setValue("myImagesPath", myImagesPath);
       s.setValue("myTemplatesPath", myTemplatesPath);
       s.setValue("myPluginsPath", myPluginsPath);
-      s.setValue("sfPath",  sfPath);
+      s.setValue("mySoundfontsPath", mySoundfontsPath);
 
       s.setValue("hraster", MScore::hRaster());
       s.setValue("vraster", MScore::vRaster());
@@ -344,6 +322,7 @@ void Preferences::write()
 
       s.setValue("workspace", workspace);
       s.setValue("exportPdfDpi", exportPdfDpi);
+      s.setValue("verticalPageOrientation", MScore::verticalOrientation());
 
       //update
       s.setValue("checkUpdateStartup", checkUpdateStartup);
@@ -395,17 +374,18 @@ void Preferences::read()
 
       MScore::defaultColor    = s.value("defaultColor", MScore::defaultColor).value<QColor>();
       MScore::dropColor       = s.value("dropColor",    MScore::dropColor).value<QColor>();
+      pianoHlColor            = s.value("pianoHlColor", pianoHlColor).value<QColor>();
 
       enableMidiInput         = s.value("enableMidiInput", enableMidiInput).toBool();
       playNotes               = s.value("playNotes", playNotes).toBool();
       playChordOnAddNote      = s.value("playChordOnAddNote", playChordOnAddNote).toBool();
 
-      showNavigator            = s.value("showNavigator", showNavigator).toBool();
-      showSplashScreen         = s.value("showSplashScreen", showSplashScreen).toBool();
-      showStartcenter          = s.value("showStartcenter1", showStartcenter).toBool();
-      showPlayPanel            = s.value("showPlayPanel", showPlayPanel).toBool();
+      showNavigator           = s.value("showNavigator", showNavigator).toBool();
+      showSplashScreen        = s.value("showSplashScreen", showSplashScreen).toBool();
+      showStartcenter         = s.value("showStartcenter1", showStartcenter).toBool();
+      showPlayPanel           = s.value("showPlayPanel", showPlayPanel).toBool();
 
-      showStatusBar   = s.value("showStatusBar", showStatusBar).toBool();
+      showStatusBar           = s.value("showStatusBar", showStatusBar).toBool();
 
       useAlsaAudio       = s.value("useAlsaAudio", useAlsaAudio).toBool();
       useJackAudio       = s.value("useJackAudio", useJackAudio).toBool();
@@ -423,7 +403,7 @@ void Preferences::read()
       portMidiInput      = s.value("portMidiInput", portMidiInput).toString();
       MScore::layoutBreakColor   = s.value("layoutBreakColor", MScore::layoutBreakColor).value<QColor>();
       MScore::frameMarginColor   = s.value("frameMarginColor", MScore::frameMarginColor).value<QColor>();
-      antialiasedDrawing = s.value("antialiasedDrawing", antialiasedDrawing).toBool();
+      antialiasedDrawing      = s.value("antialiasedDrawing", antialiasedDrawing).toBool();
 
       defaultStyleFile         = s.value("defaultStyle", defaultStyleFile).toString();
 
@@ -476,8 +456,14 @@ void Preferences::read()
       myImagesPath     = s.value("myImagesPath",     myImagesPath).toString();
       myTemplatesPath  = s.value("myTemplatesPath",  myTemplatesPath).toString();
       myPluginsPath    = s.value("myPluginsPath",    myPluginsPath).toString();
-      sfPath           = s.value("sfPath",           sfPath).toString();
-
+      // compatibility: 2.0.X with X < 3 was storing sfPath and included global path
+      mySoundfontsPath = s.value("sfPath",           mySoundfontsPath).toString();
+      s.remove("sfPath");
+      QStringList pl = mySoundfontsPath.split(";");
+      pl.removeAll(QFileInfo(QString("%1%2").arg(mscoreGlobalShare).arg("sound")).absoluteFilePath());
+      mySoundfontsPath = pl.join(";");
+      mySoundfontsPath = s.value("mySoundfontsPath", mySoundfontsPath).toString();
+      
       //Create directories if they are missing
       QDir dir;
       dir.mkpath(myScoresPath);
@@ -485,7 +471,7 @@ void Preferences::read()
       dir.mkpath(myImagesPath);
       dir.mkpath(myTemplatesPath);
       dir.mkpath(myPluginsPath);
-      foreach (QString path, sfPath.split(";"))
+      foreach (QString path, mySoundfontsPath.split(";"))
             dir.mkpath(path);
 
       MScore::setHRaster(s.value("hraster", MScore::hRaster()).toInt());
@@ -496,6 +482,7 @@ void Preferences::read()
 
       workspace          = s.value("workspace", workspace).toString();
       exportPdfDpi       = s.value("exportPdfDpi", exportPdfDpi).toInt();
+      MScore::setVerticalOrientation(s.value("verticalPageOrientation", MScore::verticalOrientation()).toBool());
 
       checkUpdateStartup = s.value("checkUpdateStartup", checkUpdateStartup).toBool();
 
@@ -618,8 +605,8 @@ PreferenceDialog::PreferenceDialog(QWidget* parent)
       connect(myTemplatesButton, SIGNAL(clicked()), SLOT(selectTemplatesDirectory()));
       connect(myPluginsButton, SIGNAL(clicked()), SLOT(selectPluginsDirectory()));
       connect(myImagesButton, SIGNAL(clicked()), SLOT(selectImagesDirectory()));
-
       connect(mySoundfontsButton, SIGNAL(clicked()), SLOT(changeSoundfontPaths()));
+
       connect(updateTranslation, SIGNAL(clicked()), SLOT(updateTranslationClicked()));
 
       connect(defaultStyleButton,     SIGNAL(clicked()), SLOT(selectDefaultStyle()));
@@ -860,6 +847,7 @@ void PreferenceDialog::updateValues()
                   }
             }
       language->blockSignals(false);
+      
       //
       // initialize local shortcut table
       //    we need a deep copy to be able to rewind all
@@ -870,6 +858,9 @@ void PreferenceDialog::updateValues()
       foreach(const Shortcut* s, Shortcut::shortcuts())
             localShortcuts[s->key()] = new Shortcut(*s);
       updateSCListView();
+      
+      //Generate the filtered Shortcut List 
+      filterShortcutsTextChanged(filterShortcuts->text());
 
       //
       // initialize portaudio
@@ -974,7 +965,7 @@ void PreferenceDialog::updateValues()
       myImages->setText(prefs.myImagesPath);
       myTemplates->setText(prefs.myTemplatesPath);
       myPlugins->setText(prefs.myPluginsPath);
-      sfPath->setText(prefs.sfPath);
+      mySoundfonts->setText(prefs.mySoundfontsPath);
 
       idx = 0;
       int n = sizeof(exportAudioSampleRates)/sizeof(*exportAudioSampleRates);
@@ -986,8 +977,7 @@ void PreferenceDialog::updateValues()
             idx = 0;
       exportAudioSampleRate->setCurrentIndex(idx);
       exportPdfDpi->setValue(prefs.exportPdfDpi);
-
-      sfChanged = false;
+      pageVertical->setChecked(MScore::verticalOrientation());
       }
 
 //---------------------------------------------------------
@@ -1007,7 +997,7 @@ void PreferenceDialog::portaudioApiActivated(int)  {}
 #endif
 
 //---------------------------------------------------------
-//   ShortcutITem
+//   ShortcutItem
 //---------------------------------------------------------
 
 bool ShortcutItem::operator<(const QTreeWidgetItem& item) const
@@ -1093,17 +1083,17 @@ void PreferenceDialog::clearShortcutClicked()
 //--------------------------------------------------------
 
 void  PreferenceDialog::filterShortcutsTextChanged(const QString &query )
-    {
-    QTreeWidgetItem *item;
-    for(int i = 0; i < shortcutList->topLevelItemCount(); i++) {
-        item = shortcutList->topLevelItem(i);
+      {
+      QTreeWidgetItem *item;
+      for(int i = 0; i < shortcutList->topLevelItemCount(); i++) {
+          item = shortcutList->topLevelItem(i);
 
-        if(item->text(0).toLower().contains(query.toLower()))
-            item->setHidden(false);
-        else
-            item->setHidden(true);
-        }
-    }
+          if(item->text(0).toLower().contains(query.toLower()))
+              item->setHidden(false);
+          else
+              item->setHidden(true);
+          }
+      }
 
 //---------------------------------------------------------
 //   selectFgWallpaper
@@ -1159,7 +1149,9 @@ void PreferenceDialog::selectInstrumentList1()
          this,
          tr("Choose Instrument List"),
          instrumentList1->text(),
-         tr("Instrument List (*.xml)")
+         tr("Instrument List (*.xml)"),
+         0,
+         preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog
          );
       if (!s.isNull())
             instrumentList1->setText(s);
@@ -1175,7 +1167,9 @@ void PreferenceDialog::selectInstrumentList2()
          this,
          tr("Choose Instrument List"),
          instrumentList2->text(),
-         tr("Instrument List (*.xml)")
+         tr("Instrument List (*.xml)"),
+         0,
+         preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog
          );
       if (!s.isNull())
             instrumentList2->setText(s);
@@ -1191,7 +1185,9 @@ void PreferenceDialog::selectStartWith()
          this,
          tr("Choose Starting Score"),
          sessionScore->text(),
-         tr("MuseScore Files (*.mscz *.mscx);;All (*)")
+         tr("MuseScore Files (*.mscz *.mscx);;All (*)"),
+         0,
+         preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog
          );
       if (!s.isNull())
             sessionScore->setText(s);
@@ -1372,7 +1368,7 @@ void PreferenceDialog::apply()
       prefs.myImagesPath       = myImages->text();
       prefs.myTemplatesPath    = myTemplates->text();
       prefs.myPluginsPath      = myPlugins->text();
-      prefs.sfPath             = sfPath->text();
+      prefs.mySoundfontsPath = mySoundfonts->text();
 
       int idx = exportAudioSampleRate->currentIndex();
       prefs.exportAudioSampleRate = exportAudioSampleRates[idx];
@@ -1399,6 +1395,18 @@ void PreferenceDialog::apply()
       prefs.pngTransparent     = pngTransparent->isChecked();
       converterDpi             = prefs.pngResolution;
       prefs.exportPdfDpi       = exportPdfDpi->value();
+      if (MScore::verticalOrientation() != pageVertical->isChecked()) {
+            MScore::setVerticalOrientation(pageVertical->isChecked());
+            for (Score* s : mscore->scores()) {
+                  s->doLayout();
+                  for (Score* ss : s->scoreList())
+                        ss->doLayout();
+                  }
+            if (mscore->currentScoreView())
+                  mscore->currentScoreView()->setOffset(0.0, 0.0);
+            mscore->scorePageLayoutChanged();
+            mscore->update();
+            }
 
       if (shortcutsChanged) {
             shortcutsChanged = false;
@@ -1606,7 +1614,8 @@ void PreferenceDialog::selectScoresDirectory()
       QString s = QFileDialog::getExistingDirectory(
          this,
          tr("Choose Score Folder"),
-         myScores->text()
+         myScores->text(),
+         QFileDialog::ShowDirsOnly | (preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog)
          );
       if (!s.isNull())
             myScores->setText(s);
@@ -1621,7 +1630,8 @@ void PreferenceDialog::selectStylesDirectory()
       QString s = QFileDialog::getExistingDirectory(
          this,
          tr("Choose Style Folder"),
-         myStyles->text()
+         myStyles->text(),
+         QFileDialog::ShowDirsOnly | (preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog)
          );
       if (!s.isNull())
             myStyles->setText(s);
@@ -1636,7 +1646,8 @@ void PreferenceDialog::selectTemplatesDirectory()
       QString s = QFileDialog::getExistingDirectory(
          this,
          tr("Choose Template Folder"),
-         myTemplates->text()
+         myTemplates->text(),
+         QFileDialog::ShowDirsOnly | (preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog)
          );
       if (!s.isNull())
             myTemplates->setText(s);
@@ -1651,7 +1662,8 @@ void PreferenceDialog::selectPluginsDirectory()
       QString s = QFileDialog::getExistingDirectory(
          this,
          tr("Choose Plugin Folder"),
-         myPlugins->text()
+         myPlugins->text(),
+         QFileDialog::ShowDirsOnly | (preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog)
          );
       if (!s.isNull())
             myPlugins->setText(s);
@@ -1666,7 +1678,8 @@ void PreferenceDialog::selectImagesDirectory()
       QString s = QFileDialog::getExistingDirectory(
          this,
          tr("Choose Image Folder"),
-         myImages->text()
+         myImages->text(),
+         QFileDialog::ShowDirsOnly | (preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog)
          );
       if (!s.isNull())
             myImages->setText(s);
@@ -1680,9 +1693,9 @@ void PreferenceDialog::changeSoundfontPaths()
       {
       PathListDialog pld(this);
       pld.setWindowTitle(tr("SoundFont Folders"));
-      pld.setPath(sfPath->text());
+      pld.setPath(mySoundfonts->text());
       if(pld.exec())
-            sfPath->setText(pld.path());
+            mySoundfonts->setText(pld.path());
       }
 
 //---------------------------------------------------------
