@@ -37,6 +37,9 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "D. Cb. Fl."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Hyperbass Flute"),
 //: Hyperbass Flute
 QT_TRANSLATE_NOOP("InstrumentsXML", "Hb. Fl."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Flute"),
+//: Baroque Flute
+QT_TRANSLATE_NOOP("InstrumentsXML", "Bq. Fl."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Danso"),
 //: Danso
 QT_TRANSLATE_NOOP("InstrumentsXML", "Da."),
@@ -54,7 +57,7 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "G Dizi"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "G Di."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "F Dizi"),
 //: F Dizi
-QT_TRANSLATE_NOOP("InstrumentsXML", "A Di."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "F Di."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "E Dizi"),
 //: E Dizi
 QT_TRANSLATE_NOOP("InstrumentsXML", "E Di."),
@@ -168,13 +171,13 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Slide Whistle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Sl. Wh."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
 //: Tin Whistle
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tin. Wh."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Wh."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Whistle"),
 //: B♭ Tin Whistle
-QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin. Wh."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Wh."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
 //: Tin Whistle
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tin. Wh."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Wh."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Oboe"),
 //: Piccolo Oboe
 QT_TRANSLATE_NOOP("InstrumentsXML", "P. Ob."),
@@ -586,10 +589,18 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cornet"),
 //: E♭ Cornet
 QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cnt."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "C Cornet"),
+//: C Cornet
+QT_TRANSLATE_NOOP("InstrumentsXML", "C Cnt."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cornet"),
 //: B♭ Cornet
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cnt."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Cornet"),
+//: A Cornet
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Cnt."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Saxhorn"),
 //: Saxhorn
 QT_TRANSLATE_NOOP("InstrumentsXML", "Saxhorn"),
@@ -628,6 +639,14 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet in A"),
 //: Piccolo Trumpet in A
 QT_TRANSLATE_NOOP("InstrumentsXML", "P. Tpt. A"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "F Trumpet"),
+//: F Trumpet
+QT_TRANSLATE_NOOP("InstrumentsXML", "F Tpt."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "E Trumpet"),
+//: E Trumpet
+QT_TRANSLATE_NOOP("InstrumentsXML", "E Tpt."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Trumpet"),
 //: E♭ Trumpet
 QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tpt."),
@@ -644,6 +663,10 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Trumpet"),
 //: B♭ Trumpet
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tpt."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Trumpet"),
+//: A Trumpet
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Tpt."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Pocket Trumpet"),
 //: Pocket Trumpet
 QT_TRANSLATE_NOOP("InstrumentsXML", "Pkt. Tpt."),
@@ -763,26 +786,26 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Serpent"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Spt."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
 //: Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
 //: Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone (Treble Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Trombone"),
 //: Soprano Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "S. Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "S. Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Trombone"),
 //: Alto Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "A. Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "A. Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Trombone"),
 //: Tenor Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "T. Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "T. Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trombone"),
 //: Bass Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "B. Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "B. Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Trombone"),
 //: Contrabass Trombone
-QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Trb."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Cb. Tbn."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Cimbasso"),
 //: Cimbasso
 QT_TRANSLATE_NOOP("InstrumentsXML", "Cim."),
@@ -1412,6 +1435,9 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar"),
 //: Classical Guitar
 QT_TRANSLATE_NOOP("InstrumentsXML", "Guit."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Contra Guitar"),
+//: Contra Guitar
+QT_TRANSLATE_NOOP("InstrumentsXML", "C Guit."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar"),
 //: Acoustic Guitar
 QT_TRANSLATE_NOOP("InstrumentsXML", "Guit."),
@@ -1556,12 +1582,12 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncello"),
 //: Violoncello
-QT_TRANSLATE_NOOP("InstrumentsXML", "Vlc."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Vc."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncellos"),
 //: Violoncellos
-QT_TRANSLATE_NOOP("InstrumentsXML", "Vlcs."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Vcs."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass"),
@@ -1580,18 +1606,28 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Db."),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Pardessus de viole"),
 //: Pardessus de viole
 QT_TRANSLATE_NOOP("InstrumentsXML", "Pds. v."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Viol"),
 //: Treble Viol
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tr. vl."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Viol"),
 //: Alto Viol
 QT_TRANSLATE_NOOP("InstrumentsXML", "A. Vl."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Viol"),
 //: Tenor Viol
 QT_TRANSLATE_NOOP("InstrumentsXML", "T. Vl."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba"),
 //: Viola da gamba
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vla. d. g."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tab)"),
 //: Viola da gamba (Tab)
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vla. d. g."),
@@ -1599,6 +1635,10 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tablature)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Violone"),
 //: Violone
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vne."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "D Violone"),
 //: D Violone
 QT_TRANSLATE_NOOP("InstrumentsXML", "Vne."),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
